Dataloader
==========

Train your models using the new high performance C++ dataloader.
See the ``dataloader`` method on how to create dataloaders from your datasets:

.. currentmodule:: deeplake.core.dataset

.. autosummary::
    :toctree:
    :nosignatures:

    Dataset.dataloader

DeepLakeDataLoader
~~~~~~~~~~~~~~~~~~

.. currentmodule:: deeplake.enterprise

.. autoclass:: DeepLakeDataLoader()
    :members:
